/* ------------------------------------------------------------------------
   child_sync include file for XfreeCD

   Copyright 1998 by Brian C. Lane
   http://www.brianlane.com/

   ------------------------------------------------------------------------ */
int parent_sync( int fd );
int child_sync( int fd );
